@@ -10,6 +10,7 @@ sqrtSX = 1e-23
 tstart = 1000000000
 duration = 100 * 86400
 tend = tstart + duration
+detectors = "H1"
 
 # Properties of the signal
 F0 = 30.0
@@ -18,9 +19,11 @@ F2 = 0
 Alpha = np.radians(83.6292)
 Delta = np.radians(22.0144)
 tref = 0.5 * (tstart + tend)
+cosi = 0
 
 depth = 60
 h0 = sqrtSX / depth
+cosi = 1.0
 
 data = pyfstat.Writer(
     label=label,
@@ -31,10 +34,13 @@ data = pyfstat.Writer(
     F1=F1,
     F2=F2,
     duration=duration,
+    detectors=detectors,
     Alpha=Alpha,
     Delta=Delta,
     h0=h0,
+    cosi=cosi,
     sqrtSX=sqrtSX,
+    detectors="H1",
 )
 data.make_data()
 
