@@ -19,7 +19,9 @@ transient_duration = 0.5 * duration
 tref = tstart
 
 h0 = 1e-23
+cosi = 0
 sqrtSX = 1e-22
+detectors = "H1,L1"
 
 transient = pyfstat.Writer(
     label="simulated_transient_signal",
@@ -33,6 +35,8 @@ transient = pyfstat.Writer(
     Alpha=Alpha,
     Delta=Delta,
     h0=h0,
+    cosi=cosi,
+    detectors=detectors,
     sqrtSX=sqrtSX,
     transientStartTime=transient_tstart,
     transientTau=transient_duration,
