@@ -72,7 +72,7 @@ class GridSearch(BaseSearchClass):
         assumeSqrtSX=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -115,14 +115,22 @@ class GridSearch(BaseSearchClass):
             setattr(self, k, np.atleast_1d(getattr(self, k + "s")))
         self.output_file_header = self.get_output_file_header()
 
+    def _get_search_ranges(self):
+        if (self.minCoverFreq is None) or (self.maxCoverFreq is None):
+            return {key: getattr(self, key + "s") for key in self.search_keys}
+        else:
+            return None
+
     def inititate_search_object(self):
         logging.info("Setting up search object")
+        search_ranges = self._get_search_ranges()
         if self.nsegs == 1:
             self.search = ComputeFstat(
                 tref=self.tref,
                 sftfilepattern=self.sftfilepattern,
                 minCoverFreq=self.minCoverFreq,
                 maxCoverFreq=self.maxCoverFreq,
+                search_ranges=search_ranges,
                 detectors=self.detectors,
                 minStartTime=self.minStartTime,
                 maxStartTime=self.maxStartTime,
@@ -134,11 +142,6 @@ class GridSearch(BaseSearchClass):
                 earth_ephem=self.earth_ephem,
                 sun_ephem=self.sun_ephem,
                 estimate_covering_band=self.estimate_covering_band,
-                F0s=self.F0s,
-                F1s=self.F1s,
-                F2s=self.F2s,
-                Alphas=self.Alphas,
-                Deltas=self.Deltas,
             )
             self.search.get_det_stat = self.search.get_fullycoherent_twoF
         else:
@@ -153,18 +156,14 @@ class GridSearch(BaseSearchClass):
                 maxStartTime=self.maxStartTime,
                 minCoverFreq=self.minCoverFreq,
                 maxCoverFreq=self.maxCoverFreq,
+                search_ranges=search_ranges,
                 detectors=self.detectors,
                 injectSources=self.injectSources,
                 estimate_covering_band=self.estimate_covering_band,
-                F0s=self.F0s,
-                F1s=self.F1s,
-                F2s=self.F2s,
-                Alphas=self.Alphas,
-                Deltas=self.Deltas,
             )
 
             def cut_out_tstart_tend(*vals):
-                return self.search.get_semicoherent_twoF(*vals[2:])
+                return self.search.get_semicoherent_det_stat(*vals[2:])
 
             self.search.get_det_stat = cut_out_tstart_tend
 
@@ -306,11 +305,11 @@ class GridSearch(BaseSearchClass):
                 rtol[n] = 0
                 atol[n] = 0
             elif f.endswith("g"):
-                precision = int(re.findall("\d+", f)[-1])
+                precision = int(re.findall(r"\d+", f)[-1])
                 rtol[n] = 10 ** (1 - precision)
                 atol[n] = 0
             elif f.endswith("f"):
-                decimals = int(re.findall("\d+", f)[-1])
+                decimals = int(re.findall(r"\d+", f)[-1])
                 rtol[n] = 0
                 atol[n] = 10 ** -decimals
             else:
@@ -542,25 +541,13 @@ class GridSearch(BaseSearchClass):
             'F2', 'Alpha', 'Delta' and 'twoF' of maximum
 
         """
-
-        twoF = self.data[:, -1]
-        idx = np.argmax(twoF)
-        v = self.data[idx, :]
-        d = OrderedDict(
-            minStartTime=v[0],
-            maxStartTime=v[1],
-            F0=v[2],
-            F1=v[3],
-            F2=v[4],
-            Alpha=v[5],
-            Delta=v[6],
-            twoF=v[7],
-        )
+        idx = np.argmax(self.data[:, self.keys.index("twoF")])
+        d = OrderedDict([(key, self.data[idx, k]) for k, key in enumerate(self.keys)])
         return d
 
     def print_max_twoF(self):
         d = self.get_max_twoF()
-        print("Max twoF values for {}:".format(self.label))
+        print("Grid point with max(twoF) for {}:".format(self.label))
         for k, v in d.items():
             print("  {}={}".format(k, v))
 
@@ -621,7 +608,7 @@ class TransientGridSearch(GridSearch):
         cudaDeviceName=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -688,11 +675,13 @@ class TransientGridSearch(GridSearch):
 
     def inititate_search_object(self):
         logging.info("Setting up search object")
+        search_ranges = self._get_search_ranges()
         self.search = ComputeFstat(
             tref=self.tref,
             sftfilepattern=self.sftfilepattern,
             minCoverFreq=self.minCoverFreq,
             maxCoverFreq=self.maxCoverFreq,
+            search_ranges=search_ranges,
             detectors=self.detectors,
             transientWindowType=self.transientWindowType,
             t0Band=self.t0Band,
@@ -713,11 +702,6 @@ class TransientGridSearch(GridSearch):
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
             estimate_covering_band=self.estimate_covering_band,
-            F0s=self.F0s,
-            F1s=self.F1s,
-            F2s=self.F2s,
-            Alphas=self.Alphas,
-            Deltas=self.Deltas,
         )
         self.search.get_det_stat = self.search.get_fullycoherent_twoF
 
@@ -733,10 +717,10 @@ class TransientGridSearch(GridSearch):
 
         data = []
         if self.outputTransientFstatMap:
-            tCWfilebase = os.path.splitext(self.out_file)[0] + "_tCW_"
+            self.tCWfilebase = os.path.splitext(self.out_file)[0] + "_tCW_"
             logging.info(
                 "Will save per-Doppler Fstatmap"
-                " results to {}*.dat".format(tCWfilebase)
+                " results to {}*.dat".format(self.tCWfilebase)
             )
         self.timingFstatMap = 0.0
         for vals in tqdm(self.input_data):
@@ -753,18 +737,21 @@ class TransientGridSearch(GridSearch):
                 if self.outputTransientFstatMap:
                     # per-Doppler filename convention:
                     # freq alpha delta f1dot f2dot
-                    tCWfile = tCWfilebase + "%.16f_%.16f_%.16f_%.16g_%.16g.dat" % (
-                        vals[2],
-                        vals[5],
-                        vals[6],
-                        vals[3],
-                        vals[4],
+                    tCWfile = (
+                        self.tCWfilebase
+                        + "{:.16f}_{:.16f}_{:.16f}_{:.16g}_{:.16g}.dat".format(
+                            vals[self.keys.index("F0")],
+                            vals[self.keys.index("Alpha")],
+                            vals[self.keys.index("Delta")],
+                            vals[self.keys.index("F1")],
+                            vals[self.keys.index("F2")],
+                        )
                     )
                     if self.tCWFstatMapVersion == "lal":
                         fo = lal.FileOpen(tCWfile, "w")
                         for hline in self.output_file_header:
                             lal.FilePuts("# {:s}\n".format(hline), fo)
-                        lal.FilePuts("# t0 [s]     tau [s]     2F\n", fo)
+                        lal.FilePuts("# t0[s]      tau[s]      2F\n", fo)
                         lalpulsar.write_transientFstatMap_to_fp(
                             fo, FstatMap, windowRange, None
                         )
@@ -809,7 +796,7 @@ class TransientGridSearch(GridSearch):
     def write_F_mn(self, tCWfile, F_mn, windowRange):
         with open(tCWfile, "w") as tfp:
             for hline in self.output_file_header:
-                tpf.write("# {:s}\n".format(hline))
+                tfp.write("# {:s}\n".format(hline))
             tfp.write("# t0 [s]     tau [s]     2F\n")
             for m, F_m in enumerate(F_mn):
                 this_t0 = windowRange.t0 + m * windowRange.dt0
@@ -853,7 +840,7 @@ class SliceGridSearch(GridSearch):
         Lambda0=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -913,11 +900,11 @@ class SliceGridSearch(GridSearch):
             self.label,
             self.outdir,
             self.sftfilepattern,
-            F0s=self.Lambda0[0],
-            F1s=self.Lambda0[1],
-            F2s=self.F2s[0],
-            Alphas=self.Lambda0[2],
-            Deltas=self.Lambda0[3],
+            F0s=[self.Lambda0[0]],
+            F1s=[self.Lambda0[1]],
+            F2s=[self.F2s[0]],
+            Alphas=[self.Lambda0[2]],
+            Deltas=[self.Lambda0[3]],
             tref=self.tref,
             minStartTime=self.minStartTime,
             maxStartTime=self.maxStartTime,
@@ -1021,7 +1008,7 @@ class GridUniformPriorSearch:
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         dF0 = (theta_prior["F0"]["upper"] - theta_prior["F0"]["lower"]) / NF0
         dF1 = (theta_prior["F1"]["upper"] - theta_prior["F1"]["lower"]) / NF1
@@ -1083,7 +1070,7 @@ class GridGlitchSearch(GridSearch):
         detectors=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Run a single-glitch grid search
@@ -1126,6 +1113,7 @@ class GridGlitchSearch(GridSearch):
         self.keys += ["twoF"]
         for k in self.search_keys:
             setattr(self, k, np.atleast_1d(getattr(self, k + "s")))
+        search_ranges = self._get_search_ranges()
 
         self.search = SemiCoherentGlitchSearch(
             label=label,
@@ -1136,15 +1124,11 @@ class GridGlitchSearch(GridSearch):
             maxStartTime=maxStartTime,
             minCoverFreq=minCoverFreq,
             maxCoverFreq=maxCoverFreq,
+            search_ranges=search_ranges,
             BSGL=self.BSGL,
             earth_ephem=earth_ephem,
             sun_ephem=sun_ephem,
             estimate_covering_band=self.estimate_covering_band,
-            F0s=self.F0s,
-            F1s=self.F1s,
-            F2s=self.F2s,
-            Alphas=self.Alphas,
-            Deltas=self.Deltas,
         )
         self.search.get_det_stat = self.search.get_semicoherent_nglitch_twoF
 
@@ -1191,7 +1175,7 @@ class SlidingWindow(GridSearch):
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1222,11 +1206,13 @@ class SlidingWindow(GridSearch):
 
     def inititate_search_object(self):
         logging.info("Setting up search object")
+        search_ranges = self._get_search_ranges()
         self.search = ComputeFstat(
             tref=self.tref,
             sftfilepattern=self.sftfilepattern,
             minCoverFreq=self.minCoverFreq,
             maxCoverFreq=self.maxCoverFreq,
+            search_ranges=search_ranges,
             detectors=self.detectors,
             transient=True,
             minStartTime=self.minStartTime,
@@ -1238,11 +1224,6 @@ class SlidingWindow(GridSearch):
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
             estimate_covering_band=self.estimate_covering_band,
-            F0s=self.F0s,
-            F1s=self.F1s,
-            F2s=self.F2s,
-            Alphas=self.Alphas,
-            Deltas=self.Deltas,
         )
 
     def check_old_data_is_okay_to_use(self, out_file):
@@ -1336,7 +1317,7 @@ class FrequencySlidingWindow(GridSearch):
         injectSources=None,
         earth_ephem=None,
         sun_ephem=None,
-        estimate_covering_band=False,
+        estimate_covering_band=None,
     ):
         """
         Parameters
@@ -1372,16 +1353,19 @@ class FrequencySlidingWindow(GridSearch):
         self.Deltas = [Delta]
         self.input_arrays = False
         self.keys = ["minStartTime", "maxStartTime", "F0", "F1", "F2", "Alpha", "Delta"]
-        self.search_keys = [x + "s" for x in self.keys[2:]]
+        # self.search_keys = [x + "s" for x in self.keys[2:]] # this was different from other classes
+        self.search_keys = self.keys[2:]
         self.output_file_header = self.get_output_file_header()
 
     def inititate_search_object(self):
         logging.info("Setting up search object")
+        search_ranges = self._get_search_ranges()
         self.search = ComputeFstat(
             tref=self.tref,
             sftfilepattern=self.sftfilepattern,
             minCoverFreq=self.minCoverFreq,
             maxCoverFreq=self.maxCoverFreq,
+            search_ranges=search_ranges,
             detectors=self.detectors,
             transientWindowType=self.transientWindowType,
             minStartTime=self.minStartTime,
@@ -1393,11 +1377,6 @@ class FrequencySlidingWindow(GridSearch):
             earth_ephem=self.earth_ephem,
             sun_ephem=self.sun_ephem,
             estimate_covering_band=self.estimate_covering_band,
-            F0s=self.F0s,
-            F1s=self.F1s,
-            F2s=self.F2s,
-            Alphas=self.Alphas,
-            Deltas=self.Deltas,
         )
         self.search.get_det_stat = self.search.get_fullycoherent_twoF
 
