@@ -30,30 +30,31 @@ class Writer(BaseSearchClass):
     @helper_functions.initializer
     def __init__(
         self,
-        label="Test",
-        tstart=700000000,
-        duration=100 * 86400,
+        label="PyFstat",
+        tstart=None,
+        duration=None,
         tref=None,
-        F0=30,
-        F1=1e-10,
+        F0=None,
+        F1=0,
         F2=0,
-        Alpha=5e-3,
-        Delta=6e-2,
-        h0=0.1,
-        cosi=0.0,
+        Alpha=None,
+        Delta=None,
+        h0=None,
+        cosi=None,
         psi=0.0,
         phi=0,
         Tsft=1800,
         outdir=".",
-        sqrtSX=0.0,
+        sqrtSX=None,
         noiseSFTs=None,
         SFTWindowType=None,
         SFTWindowBeta=0.0,
-        Band=4,
-        detectors="H1",
+        Band=None,
+        detectors=None,
+        earth_ephem=None,
+        sun_ephem=None,
         minStartTime=None,
         maxStartTime=None,
-        add_noise=True,
         transientWindowType="none",
         transientStartTime=None,
         transientTau=None,
@@ -69,14 +70,32 @@ class Writer(BaseSearchClass):
         tref: float or None
             reference time (default is None, which sets the reference time to
             tstart)
-        F0, F1, F2, Alpha, Delta, h0, cosi, psi, phi: float
-            frequency, sky-position, and amplitude parameters
+        F0: float or None
+            frequency of signal to inject,
+            also used (if Band is not None) as center of frequency band;
+            also needed when noise-only (h0==None or ==0)
+            but no noiseSFTs given,
+            then again used as center of frequency band.
+        F1, F2, Alpha, Delta, h0, cosi, psi, phi: float or None
+            frequency evolution and amplitude parameters for injection
+            if h0==None or h0==0, these are all ignored
+            if h0>0, then Alpha, Delta, cosi need to be set explicitly
         Tsft: float
             the sft duration
+        noiseSFTs: str
+            SFT on top of which signals will be injected. 
+            If not None, additional constraints can be applied using the arguments 
+            tstart and duration.
+        Band: float or None
+            If float, and F0 is also not None, then output SFTs cover
+            [F0-Band/2,F0+Band/2].
+            If None and noiseSFTs given, use their bandwidth.
+            If None and no noiseSFTs given,
+            a minimal covering band for a perfectly-matched
+            single-template ComputeFstat analysis is estimated.
         minStartTime, maxStartTime: float
             DEPRECATED, use [tstart,duration] and/or
-            [transientWindowType,transientStartTime,transientTau] instead!
-
+            [transientWindowType,transientStartTime,transientTau] instead!    
         see `lalapps_Makefakedata_v5 --help` for help with the other paramaters
         """
 
@@ -85,38 +104,47 @@ class Writer(BaseSearchClass):
                 "Options 'minStartTime' and 'maxStartTime' are no longer supported!"
             )
 
-        self.set_ephemeris_files()
+        self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.basic_setup()
         self.calculate_fmin_Band()
 
-        self.tbounds = [self.tstart, self.tend]
-        logging.info("Using segment boundaries {}".format(self.tbounds))
+    def _get_sft_constraints_from_tstart_duration(self):
+        """
+        Use start and duration to set up a lalpulsar.SFTConstraints
+        object. This method is only used if noiseSFTs is not None.
+        """
+        SFTConstraint = lalpulsar.SFTConstraints()
 
-    def basic_setup(self):
+        if self.tstart is None:
+            SFTConstraint.minStartTime = None
+            SFTConstraint.maxStartTime = None
+        elif self.duration is None:
+            SFTConstraint.maxStartTime = None
+        else:
+            SFTConstraint.minStartTime = lal.LIGOTimeGPS(self.tstart)
+            SFTConstraint.maxStartTime = SFTConstraint.minStartTime + self.duration
+
+        SFTConstraint.timestamps = None  # FIXME: not currently supported
+
+        logging.info(
+            "SFT Constraints: [minStartTime:{}, maxStartTime:{}]".format(
+                SFTConstraint.minStartTime, SFTConstraint.maxStartTime,
+            )
+        )
+
+        return SFTConstraint
+
+    def _get_setup_from_tstart_duration(self):
+        """
+        Default behavior: If no noiseSFTs are given, use the input parameters (tstart, 
+        duration, detectors and Tsft) to make fake data.
+        """
         self.tstart = int(self.tstart)
         self.duration = int(self.duration)
-        self.tend = self.tstart + self.duration
 
         IFOs = self.detectors.split(",")
-        if self.noiseSFTs:
-            numSFTs = []
-            for ifo in IFOs:
-                constraint = lalpulsar.SFTConstraints()
-                constraint.detector = ifo
-                constraint.minStartTime = lal.LIGOTimeGPS(self.tstart)
-                constraint.maxStartTime = lal.LIGOTimeGPS(self.tend)
-                catalog = lalpulsar.SFTdataFind(self.noiseSFTs, constraint)
-                numSFTs.append(catalog.length)
-        else:
-            numSFTs = len(IFOs) * [int(float(self.duration) / self.Tsft)]
+        numSFTs = len(IFOs) * [int(float(self.duration) / self.Tsft)]
 
-        self.theta = np.array([self.phi, self.F0, self.F1, self.F2])
-
-        if os.path.isdir(self.outdir) is False:
-            os.makedirs(self.outdir)
-        if self.tref is None:
-            self.tref = self.tstart
-        self.config_file_name = os.path.join(self.outdir, self.label + ".cff")
         self.sftfilenames = [
             lalpulsar.OfficialSFTFilename(
                 dets[0],
@@ -129,14 +157,126 @@ class Writer(BaseSearchClass):
             )
             for ind, dets in enumerate(IFOs)
         ]
+
+    def _get_setup_from_noiseSFTs(self):
+        """
+        If noiseSFTs are given, use them to obtain relevant data parameters (tstart,
+        duration, detectors and Tsft). The corresponding input values will be used to
+        set up a lalpulsar.SFTConstraints object to be imposed to the SFTs. Keep in
+        mind that Tsft will also be checked to be consistent accross all SFTs (this is
+        not implemented through SFTConstraints but through a simple list check).
+        """
+        SFTConstraint = self._get_sft_constraints_from_tstart_duration()
+        noise_multi_sft_catalog = lalpulsar.GetMultiSFTCatalogView(
+            lalpulsar.SFTdataFind(self.noiseSFTs, SFTConstraint)
+        )
+        if noise_multi_sft_catalog.length == 0:
+            raise IOError("Got empty SFT catalog.")
+
+        # Information to be extracted from the SFTs themselves
+        IFOs = []
+        tstart = []
+        tend = []
+        Tsft = []
+        self.sftfilenames = []  # This refers to the MFD output!
+
+        # SWIG-LAL does not import this functionality
+        gps_to_int = lambda x: x.gpsSeconds
+
+        for ifo_catalog in noise_multi_sft_catalog.data:
+            ifo_name = lalpulsar.ListIFOsInCatalog(ifo_catalog).data[0]
+
+            time_stamps = lalpulsar.TimestampsFromSFTCatalog(ifo_catalog)
+            this_Tsft = int(round(1.0 / ifo_catalog.data[0].header.deltaF))
+            this_start_time = gps_to_int(time_stamps.data[0])
+            this_end_time = gps_to_int(time_stamps.data[-1]) + this_Tsft
+
+            self.sftfilenames.append(
+                lalpulsar.OfficialSFTFilename(
+                    ifo_name[0],
+                    ifo_name[1],
+                    ifo_catalog.length,
+                    this_Tsft,
+                    this_start_time,
+                    this_end_time - this_start_time,
+                    self.label,
+                )
+            )
+
+            IFOs.append(ifo_name)
+            tstart.append(this_start_time)
+            tend.append(this_end_time)
+            Tsft.append(this_Tsft)
+
+        # Get the "overall" values of the search
+        Tsft = np.unique(Tsft)
+        if len(Tsft) != 1:
+            raise ValueError("SFTs contain different basetimes: {}".format(Tsft))
+        elif Tsft[0] != self.Tsft:
+            raise ValueError(
+                "SFT basetime {} differs from input base time {}".format(
+                    Tsft[0], self.Tsft
+                )
+            )
+        self.tstart = min(tstart)
+        self.duration = max(tend) - self.tstart
+        self.detectors = ",".join(IFOs)
+
+    def basic_setup(self):
+        os.makedirs(self.outdir, exist_ok=True)
+        self.config_file_name = os.path.join(self.outdir, self.label + ".cff")
+        self.theta = np.array([self.phi, self.F0, self.F1, self.F2])
+
+        required_signal_params = [
+            # leaving out "F1","F2","psi","phi","tref" as they have defaults
+            "F0",
+            "Alpha",
+            "Delta",
+            "cosi",
+        ]
+        if self.h0 and np.any(
+            [getattr(self, k, None) is None for k in required_signal_params]
+        ):
+            raise ValueError(
+                "If h0>0, also need all of ({:s})".format(
+                    ",".join(required_signal_params)
+                )
+            )
+
+        no_noiseSFTs_options = ["tstart", "duration", "detectors"]
+        if self.noiseSFTs is not None:
+            logging.warning(
+                "noiseSFTs is not None: Inferring tstart, duration, Tsft. "
+                "Input tstart and duration will be treated as SFT constraints "
+                "using lalpulsar.SFTConstraints; Tsft will be checked for "
+                "internal consistency accross input SFTs."
+            )
+            self._get_setup_from_noiseSFTs()
+        elif np.any([getattr(self, k) is None for k in no_noiseSFTs_options]):
+            raise ValueError(
+                "Need either noiseSFTs or all of ({:s}).".format(
+                    ",".join(no_noiseSFTs_options)
+                )
+            )
+        else:
+            self._get_setup_from_tstart_duration()
+
         self.sftfilepath = ";".join(
             [os.path.join(self.outdir, fn) for fn in self.sftfilenames]
         )
-        self.IFOs = ",".join(['"{}"'.format(d) for d in IFOs])
 
-    def make_data(self):
+        if self.tref is None:
+            self.tref = self.tstart
+
+    def tend(self):
+        return self.tstart + self.duration
+
+    def make_data(self, verbose=False):
         """ A convienience wrapper to generate a cff file then sfts """
-        self.make_cff()
+        if self.h0:
+            self.make_cff(verbose)
+        else:
+            logging.info("Got h0=0, not writing an injection .cff file.")
         self.run_makefakedata()
 
     def get_base_template(self, i, Alpha, Delta, h0, cosi, psi, phi, F0, F1, F2, tref):
@@ -245,7 +385,7 @@ transientTau = {:10.0f}\n"""
                 transientTau,
             )
 
-    def make_cff(self):
+    def make_cff(self, verbose=False):
         """
         Generates a .cff file
 
@@ -269,12 +409,79 @@ transientTau = {:10.0f}\n"""
         )
 
         if self.check_if_cff_file_needs_rewritting(content):
+            if verbose:
+                logging.info(
+                    "Writing the following injection parameters"
+                    " to config file {:s}:".format(self.config_file_name)
+                )
+                logging.info(content)
+            else:
+                logging.info(
+                    "Writing config file {:s}...".format(self.config_file_name)
+                )
             config_file = open(self.config_file_name, "w+")
             config_file.write(content)
             config_file.close()
 
     def calculate_fmin_Band(self):
-        self.fmin = self.F0 - 0.5 * self.Band
+        """
+        Set fmin and Band for the output SFTs to cover.
+
+        Either uses the user-provided Band and puts F0 in the middle,
+        does nothing to later reuse full bandwidth of noiseSFTs,
+        or if F0!=None, noiseSFTs==None and Band==None
+        it estimates a minimal band for just the injected signal:
+        F-stat covering band plus extra bins for demod default parameters.
+        This way a perfectly matched single-template ComputeFstat analysis
+        should run through perfectly on the SFTs.
+        For any wider-band or mismatched search, the set Band manually.
+
+        If you want to use noiseSFTs but auto-estimate a minimal band,
+        call helper_functions.get_covering_band() yourself
+        and pass the results as fmin, Band.
+        """
+        if self.F0 is not None and self.Band is not None:
+            self.fmin = self.F0 - 0.5 * self.Band
+        elif self.noiseSFTs:
+            logging.info("Generating SFTs with full bandwidth from noiseSFTs.")
+        elif self.F0 is None:
+            raise ValueError(
+                "Need F0 and Band, or one of (F0 or noiseSFTs)"
+                " to auto-estimate bandwidth."
+            )
+        else:
+            extraBins = (
+                # matching extraBinsFull in XLALCreateFstatInput():
+                # https://lscsoft.docs.ligo.org/lalsuite/lalpulsar/_compute_fstat_8c_source.html#l00490
+                lalpulsar.FstatOptionalArgsDefaults.Dterms
+                + int(lalpulsar.FstatOptionalArgsDefaults.runningMedianWindow / 2)
+                + 1
+            )
+            logging.info(
+                "Estimating required SFT frequency range from properties"
+                " of signal to inject plus {:d} extra bins either side"
+                " (corresponding to default F-statistic settings).".format(extraBins)
+            )
+            minCoverFreq, maxCoverFreq = helper_functions.get_covering_band(
+                tref=self.tref,
+                tstart=self.tstart,
+                tend=self.tend(),
+                F0=self.F0,
+                F1=self.F1,
+                F2=self.F2,
+                F0band=0.0,
+                F1band=0.0,
+                F2band=0.0,
+                maxOrbitAsini=getattr(self, "asini", 0.0),
+                minOrbitPeriod=getattr(self, "period", 0.0),
+                maxOrbitEcc=getattr(self, "ecc", 0.0),
+            )
+            self.fmin = minCoverFreq - extraBins / self.Tsft
+            self.Band = maxCoverFreq - minCoverFreq + 2 * extraBins / self.Tsft
+        if hasattr(self, "fmin"):
+            logging.info(
+                "Generating SFTs with fmin={}, Band={}".format(self.fmin, self.Band)
+            )
 
     def check_cached_data_okay_to_use(self, cl_mfd):
         """ Check if cached data exists and, if it does, if it can be used """
@@ -382,38 +589,38 @@ transientTau = {:10.0f}\n"""
         cl_mfd.append('--outSFTdir="{}"'.format(self.outdir))
         cl_mfd.append('--outLabel="{}"'.format(self.label))
 
-        if self.add_noise:
-            if self.noiseSFTs is not None and self.SFTWindowType is None:
-                raise ValueError(
-                    "SFTWindowType is required when using noiseSFTs. "
-                    "Please, make sure you understand the window function used "
-                    "to produce noiseSFTs."
-                )
-            elif self.noiseSFTs is not None:
-                if self.sqrtSX > 0.0:
-                    logging.warning(
-                        "In addition to using noiseSFTs, you are adding "
-                        "Gaussian noise with sqrtSX={} "
-                        "Please, make sure this is what you intend to do.".format(
-                            self.sqrtSX
-                        )
+        if self.noiseSFTs is not None and self.SFTWindowType is None:
+            raise ValueError(
+                "SFTWindowType is required when using noiseSFTs. "
+                "Please, make sure you understand the window function used "
+                "to produce noiseSFTs."
+            )
+        elif self.noiseSFTs is not None:
+            if self.sqrtSX and self.sqrtSX > 0.0:
+                logging.warning(
+                    "In addition to using noiseSFTs, you are adding "
+                    "Gaussian noise with sqrtSX={} "
+                    "Please, make sure this is what you intend to do.".format(
+                        self.sqrtSX
                     )
-                cl_mfd.append('--noiseSFTs="{}"'.format(self.noiseSFTs))
-            else:
-                cl_mfd.append("--IFOs={}".format(self.IFOs))
-            cl_mfd.append('--sqrtSX="{}"'.format(self.sqrtSX))
+                )
+            cl_mfd.append('--noiseSFTs="{}"'.format(self.noiseSFTs))
         else:
-            cl_mfd.append("--IFOs={}".format(self.IFOs))
+            cl_mfd.append('--IFOs="{}"'.format(self.detectors))
+        if self.sqrtSX:
+            cl_mfd.append('--sqrtSX="{}"'.format(self.sqrtSX))
 
         if self.SFTWindowType is not None:
             cl_mfd.append('--SFTWindowType="{}"'.format(self.SFTWindowType))
             cl_mfd.append("--SFTWindowBeta={}".format(self.SFTWindowBeta))
         cl_mfd.append("--startTime={}".format(self.tstart))
         cl_mfd.append("--duration={}".format(self.duration))
-        cl_mfd.append("--fmin={:.16g}".format(self.fmin))
-        cl_mfd.append("--Band={:.16g}".format(self.Band))
+        if hasattr(self, "fmin") and self.fmin:
+            cl_mfd.append("--fmin={:.16g}".format(self.fmin))
+        if hasattr(self, "Band") and self.Band:
+            cl_mfd.append("--Band={:.16g}".format(self.Band))
         cl_mfd.append("--Tsft={}".format(self.Tsft))
-        if self.h0 != 0:
+        if self.h0:
             cl_mfd.append('--injectionSources="{}"'.format(self.config_file_name))
         earth_ephem = getattr(self, "earth_ephem", None)
         sun_ephem = getattr(self, "sun_ephem", None)
@@ -428,6 +635,7 @@ transientTau = {:10.0f}\n"""
         check_ok = self.check_cached_data_okay_to_use(cl_mfd)
         if check_ok is False:
             helper_functions.run_commandline(cl_mfd)
+        logging.info("Successfully wrote SFTs to: {}".format(self.sftfilepath))
 
     def predict_fstat(self, assumeSqrtSX=None):
         """ Wrapper to lalapps_PredictFstat """
@@ -440,7 +648,7 @@ transientTau = {:10.0f}\n"""
             Freq=self.F0,
             sftfilepattern=self.sftfilepath,
             minStartTime=self.tstart,
-            maxStartTime=self.tend,
+            maxStartTime=self.tend(),
             IFOs=self.detectors,
             assumeSqrtSX=(assumeSqrtSX or self.sqrtSX),
             tempory_filename=os.path.join(self.outdir, self.label + ".tmp"),
@@ -449,7 +657,7 @@ transientTau = {:10.0f}\n"""
             transientWindowType=self.transientWindowType,
             transientStartTime=self.transientStartTime,
             transientTau=self.transientTau,
-        )  # detectors OR IFO?
+        )
         return twoF_expected
 
 
@@ -459,35 +667,36 @@ class BinaryModulatedWriter(Writer):
     @helper_functions.initializer
     def __init__(
         self,
-        label="Test",
-        tstart=700000000,
-        duration=100 * 86400,
+        label="PyFstat",
+        tstart=None,
+        duration=None,
         tref=None,
-        F0=30,
-        F1=1e-10,
+        F0=None,
+        F1=0,
         F2=0,
-        Alpha=5e-3,
-        Delta=6e-2,
+        Alpha=None,
+        Delta=None,
         tp=0.0,
         argp=0.0,
         asini=0.0,
         ecc=0.0,
         period=0.0,
-        h0=0.1,
-        cosi=0.0,
+        h0=None,
+        cosi=None,
         psi=0.0,
         phi=0,
         Tsft=1800,
         outdir=".",
-        sqrtSX=0.0,
+        sqrtSX=None,
         noiseSFTs=None,
         SFTWindowType=None,
         SFTWindowBeta=0.0,
-        Band=4,
-        detectors="H1",
+        Band=None,
+        detectors=None,
+        earth_ephem=None,
+        sun_ephem=None,
         minStartTime=None,
         maxStartTime=None,
-        add_noise=True,
         transientWindowType="none",
         transientStartTime=None,
         transientTau=None,
@@ -503,7 +712,7 @@ class BinaryModulatedWriter(Writer):
         tref: float or None
             reference time (default is None, which sets the reference time to
             tstart)
-        F0, F1, F2, Alpha, Delta, orbitTp, orbitArgp, orbitasini, orbitEcc, h0, cosi, psi, phi: float
+        F0, F1, F2, Alpha, Delta, tp, argp, asini, ecc, period, h0, cosi, psi, phi: float
             frequency, sky-position, binary orbit and amplitude parameters
         Tsft: float
             the sft duration
@@ -534,7 +743,8 @@ class BinaryModulatedWriter(Writer):
             noiseSFTs=noiseSFTs,
             Band=Band,
             detectors=detectors,
-            add_noise=add_noise,
+            earth_ephem=earth_ephem,
+            sun_ephem=sun_ephem,
             transientWindowType=transientWindowType,
             transientStartTime=transientStartTime,
             transientTau=transientTau,
@@ -572,9 +782,9 @@ class BinaryModulatedWriter(Writer):
             key: value for key, value in signal_parameters.items() if value is not None
         }
 
-        signal_parameter_formats = (len(signal_parameter_labels) - 1) * [":1.18e"] + [
-            ":s"
-        ]
+        signal_parameter_formats = (
+            [":10.6f"] + (len(signal_parameter_labels) - 2) * [":1.18e"] + [":s"]
+        )
         signal_formats = dict(zip(signal_parameter_labels, signal_parameter_formats))
 
         self.signal_parameters = translate_keys_to_lal(self.signal_parameters)
@@ -604,13 +814,21 @@ class BinaryModulatedWriter(Writer):
 
         return config_line
 
-    def make_cff(self):
+    def make_cff(self, verbose=False):
         """
         Generates a .cff file
 
         """
+
         content = self.get_single_config_line(0)
 
+        if verbose:
+            logging.info(
+                "Writing the following injection parameters"
+                " to config file {:s}:".format(self.config_file_name)
+            )
+            logging.info(content)
+
         if self.check_if_cff_file_needs_rewritting(content):
             config_file = open(self.config_file_name, "w+")
             config_file.write(content)
@@ -623,35 +841,36 @@ class GlitchWriter(Writer):
     @helper_functions.initializer
     def __init__(
         self,
-        label="Test",
-        tstart=700000000,
-        duration=100 * 86400,
+        label="PyFstat",
+        tstart=None,
+        duration=None,
         dtglitch=None,
         delta_phi=0,
         delta_F0=0,
         delta_F1=0,
         delta_F2=0,
         tref=None,
-        F0=30,
-        F1=1e-10,
+        F0=None,
+        F1=0,
         F2=0,
-        Alpha=5e-3,
-        Delta=6e-2,
-        h0=0.1,
-        cosi=0.0,
+        Alpha=None,
+        Delta=None,
+        h0=None,
+        cosi=None,
         psi=0.0,
         phi=0,
         Tsft=1800,
         outdir=".",
-        sqrtSX=0.0,
+        sqrtSX=None,
         noiseSFTs=None,
         SFTWindowType=None,
         SFTWindowBeta=0.0,
-        Band=4,
-        detectors="H1",
+        Band=None,
+        detectors=None,
+        earth_ephem=None,
+        sun_ephem=None,
         minStartTime=None,
         maxStartTime=None,
-        add_noise=True,
         transientWindowType="rect",
         randSeed=None,
     ):
@@ -685,7 +904,7 @@ class GlitchWriter(Writer):
                 "Options 'minStartTime' and 'maxStartTime' are no longer supported!"
             )
 
-        self.set_ephemeris_files()
+        self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.basic_setup()
         self.calculate_fmin_Band()
 
@@ -703,11 +922,11 @@ class GlitchWriter(Writer):
                 d = np.atleast_1d(d)
 
         if self.dtglitch is None:
-            self.tbounds = [self.tstart, self.tend]
+            self.tbounds = [self.tstart, self.tend()]
         else:
             self.dtglitch = np.atleast_1d(self.dtglitch)
             self.tglitch = self.tstart + self.dtglitch
-            self.tbounds = np.concatenate(([self.tstart], self.tglitch, [self.tend]))
+            self.tbounds = np.concatenate(([self.tstart], self.tglitch, [self.tend()]))
         logging.info("Using segment boundaries {}".format(self.tbounds))
 
         tbs = np.array(self.tbounds)
@@ -717,7 +936,7 @@ class GlitchWriter(Writer):
             np.array([delta_phi, delta_F0, delta_F1, delta_F2]).T
         )
 
-    def make_cff(self):
+    def make_cff(self, verbose=False):
         """
         Generates an .cff file for a 'glitching' signal
 
@@ -746,6 +965,13 @@ class GlitchWriter(Writer):
 
             content += line
 
+        if verbose:
+            logging.info(
+                "Writing the following injection parameters"
+                " to config file {:s}:".format(self.config_file_name)
+            )
+            logging.info(content)
+
         if self.check_if_cff_file_needs_rewritting(content):
             config_file = open(self.config_file_name, "w+")
             config_file.write(content)
@@ -774,10 +1000,11 @@ class FrequencyModulatedArtifactWriter(Writer):
         Pmod_amp=1,
         Alpha=None,
         Delta=None,
-        IFO="H1",
         minStartTime=None,
         maxStartTime=None,
-        detectors="H1",
+        detectors=None,
+        earth_ephem=None,
+        sun_ephem=None,
         randSeed=None,
     ):
         """
@@ -809,7 +1036,7 @@ class FrequencyModulatedArtifactWriter(Writer):
         self.F2 = 0
 
         self.basic_setup()
-        self.set_ephemeris_files()
+        self.set_ephemeris_files(earth_ephem, sun_ephem)
         self.tstart = int(tstart)
         self.duration = int(duration)
 
@@ -854,10 +1081,14 @@ class FrequencyModulatedArtifactWriter(Writer):
             # Pos and vel returned in units of c
             DeltaFOrbital = np.dot(self.n, orbit_posvel.vel) * self.Fmax
 
-            if self.IFO == "H1":
+            if self.detectors == "H1":
                 Lambda = lal.LHO_4K_DETECTOR_LATITUDE_RAD
-            elif self.IFO == "L1":
+            elif self.detectors == "L1":
                 Lambda = lal.LLO_4K_DETECTOR_LATITUDE_RAD
+            else:
+                raise ValueError(
+                    "This class currently only supports detectors H1 or L1."
+                )
 
             DeltaFSpin = (
                 self.Pmod_amp
@@ -881,8 +1112,8 @@ class FrequencyModulatedArtifactWriter(Writer):
 
     def concatenate_sft_files(self):
         SFTFilename = lalpulsar.OfficialSFTFilename(
-            self.IFO[0],
-            self.IFO[1],
+            self.detectors[0],
+            self.detectors[1],
             self.nsfts,
             self.Tsft,
             int(self.tstart),
@@ -994,7 +1225,7 @@ class FrequencyModulatedArtifactWriter(Writer):
         cl_mfd.append("lalapps_Makefakedata_v4")
         cl_mfd.append("--outSingleSFT=FALSE")
         cl_mfd.append('--outSFTbname="{}"'.format(tmp_outdir))
-        cl_mfd.append("--IFO={}".format(self.IFO))
+        cl_mfd.append("--IFO={}".format(self.detectors))
         cl_mfd.append('--noiseSqrtSh="{}"'.format(self.sqrtSX))
         cl_mfd.append("--startTime={:0.0f}".format(mid_time - self.Tsft / 2.0))
         cl_mfd.append("--refTime={:0.0f}".format(mid_time))
